@@ -30,17 +30,25 @@
 #include <arpa/inet.h>
 #include "libpacketdump.h"
 
+#include <assert.h>
 
-DLLEXPORT void decode(int link_type UNUSED,const char *packet,unsigned len) {
-	
-	libtrace_ospf_summary_lsa_v2_t *sum = (libtrace_ospf_summary_lsa_v2_t *)packet;
+DLLEXPORT void decode(int link_type UNUSED, const char *packet, unsigned len)
+{
 
-	if (len >= 4) {
-		printf(" OSPF Summary LSA (ASBR): Netmask %s ", inet_ntoa(sum->netmask));
-	}
+    unsigned char *lsa_ptr = (unsigned char *)packet;
+    uint32_t rem = len;
+    uint16_t lsa_length = 0;
+    uint8_t lsa_type;
+    libtrace_ospf_lsa_v2_t *lsa_hdr;
 
-	if (len < 8) 
-		return;
-	
-	printf("Metric %u\n", trace_get_ospf_metric_from_summary_lsa_v2(sum));
+    while (trace_get_next_ospf_lsa_header_v2(&lsa_ptr, &lsa_hdr, &rem,
+                                             &lsa_type, &lsa_length) > 0) {
+
+        if (lsa_hdr) {
+            decode_next((char *)lsa_hdr, lsa_length, "ospf2", 1000);
+        }
+
+        /* These packets contain LSA headers only so don't try to
+         * decode the body */
+    }
 }
